==> nmrium-0.53.0.tgz: package/lib/component/hooks/useSaveSettings.js <==
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Dialog } from '@blueprintjs/core';
import { Formik } from 'formik';
import { useRef, forwardRef } from 'react';
import { useOnOff } from 'react-science/ui';
import * as Yup from 'yup';
import { usePreferences } from '../context/PreferencesContext';
import { useToaster } from '../context/ToasterContext';
import FormikInput from '../elements/formik/FormikInput';
import ConfirmationDialog from '../elements/popup/Modal/ConfirmDialog';
const schema = Yup.object().shape({
    workspaceName: Yup.string().required(),
});
const WorkspaceAddForm = forwardRef(({ className, message, onSave }, ref) => {
    return (_jsxs("div", { className: className, children: [_jsx("p", { style: { paddingBottom: '10px' }, children: message }), _jsx(Formik, { initialValues: { workspaceName: '' }, validationSchema: schema, onSubmit: onSave, innerRef: ref, children: _jsx(FormikInput, { name: "workspaceName", placeholder: "Enter workspace Name", style: {
                        input: {
                            padding: '0.5em',
                            width: '90%',
                            fontWeight: 'normal',
                            color: 'black',
                        },
                    }, autoFocus: true }) })] }));
});
export function useSaveSettings() {
    const toaster = useToaster();
    const [isOpenDialog, openDialog, closeDialog] = useOnOff(false);
    const settingsRef = useRef();
    const { dispatch, current } = usePreferences();
    const formRef = useRef(null);
    function addNewWorkspace({ workspaceName }) {
        dispatch({
            type: 'ADD_WORKSPACE',
            payload: {
                workspaceKey: workspaceName,
                data: settingsRef.current,
            },
        });
        closeDialog();
        toaster.show({
            message: 'Preferences saved successfully',
            intent: 'success',
        });
    }
    return {
        saveSettings: (values) => {
            settingsRef.current = values;
            if (current.source !== 'user') {
                openDialog();
            }
            else {
                dispatch({
                    type: 'SET_PREFERENCES',
                    ...(values && { payload: values }),
                });
                closeDialog();
            }
        },
        SaveSettingsModal: () => {
            const alertConfig = {
                message: 'Please enter a new user workspace name in order to save your changes locally',
                render: (props) => (_jsx(WorkspaceAddForm, { ...props, onSave: addNewWorkspace, ref: formRef })),
                buttons: [
                    {
                        text: 'Save',
                        handler: () => {
                            void formRef.current?.submitForm();
                        },
                        preventClose: true,
                    },
                    { text: 'Cancel' },
                ],
                id: 'save-workspace-dialog',
                onClose: closeDialog,
            };
            return (_jsx(Dialog, { onClose: closeDialog, isOpen: isOpenDialog, title: "Save workspace", children: _jsx(ConfirmationDialog, { disableDefaultStyle: true, ...alertConfig }) }));
        },
    };
}

==> nmrium-0.55.0.tgz: package/lib/component/hooks/useSaveSettings.js <==
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Dialog } from '@blueprintjs/core';
import { Formik } from 'formik';
import { useRef, forwardRef } from 'react';
import { useOnOff } from 'react-science/ui';
import * as Yup from 'yup';
import { usePreferences } from '../context/PreferencesContext';
import { useToaster } from '../context/ToasterContext';
import FormikInput from '../elements/formik/FormikInput';
import ConfirmationDialog from '../elements/popup/Modal/ConfirmDialog';
import { useWorkspaceAction } from './useWorkspaceAction';
const schema = Yup.object().shape({
    workspaceName: Yup.string().required(),
});
const WorkspaceAddForm = forwardRef(({ className, message, onSave }, ref) => {
    return (_jsxs("div", { className: className, children: [_jsx("p", { style: { paddingBottom: '10px' }, children: message }), _jsx(Formik, { initialValues: { workspaceName: '' }, validationSchema: schema, onSubmit: onSave, innerRef: ref, children: _jsx(FormikInput, { name: "workspaceName", placeholder: "Enter workspace Name", style: {
                        input: {
                            padding: '0.5em',
                            width: '90%',
                            fontWeight: 'normal',
                            color: 'black',
                        },
                    }, autoFocus: true }) })] }));
});
export function useSaveSettings() {
    const toaster = useToaster();
    const [isOpenDialog, openDialog, closeDialog] = useOnOff(false);
    const settingsRef = useRef();
    const { current } = usePreferences();
    const formRef = useRef(null);
    const { saveWorkspace, addNewWorkspace } = useWorkspaceAction();
    function handleAddNewWorkspace({ workspaceName }) {
        addNewWorkspace(workspaceName, settingsRef.current);
        closeDialog();
        toaster.show({
            message: 'Preferences saved successfully',
            intent: 'success',
        });
    }
    return {
        saveSettings: (values) => {
            settingsRef.current = values;
            if (current.source !== 'user') {
                openDialog();
            }
            else {
                saveWorkspace(values);
                closeDialog();
            }
        },
        SaveSettingsModal: () => {
            const alertConfig = {
                message: 'Please enter a new user workspace name in order to save your changes locally',
                render: (props) => (_jsx(WorkspaceAddForm, { ...props, onSave: handleAddNewWorkspace, ref: formRef })),
                buttons: [
                    {
                        text: 'Save',
                        handler: () => {
                            void formRef.current?.submitForm();
                        },
                        preventClose: true,
                    },
                    { text: 'Cancel' },
                ],
                id: 'save-workspace-dialog',
                onClose: closeDialog,
            };
            return (_jsx(Dialog, { onClose: closeDialog, isOpen: isOpenDialog, title: "Save workspace", children: _jsx(ConfirmationDialog, { disableDefaultStyle: true, ...alertConfig }) }));
        },
    };
}
